#
# spec file for package just
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with     tests
Name:           just
Version:        1.41.0
Release:        1.1
Summary:        Commmand runner
License:        (Apache-2.0 OR MIT) AND Unicode-DFS-2016 AND (Apache-2.0 OR BSL-1.0) AND (Apache-2.0 OR MIT) AND (Apache-2.0 OR Apache-2.0 WITH LLVM-exception OR MIT) AND (MIT OR Unlicense) AND Apache-2.0 AND BSD-3-Clause AND CC0-1.0 AND MIT AND CC0-1.0
Group:          Development/Tools/Building
URL:            https://github.com/casey/just
Source0:        https://github.com/casey/just/archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        vendor.tar.zst
BuildRequires:  bash-completion
BuildRequires:  cargo-packaging
BuildRequires:  fish
BuildRequires:  git-core
BuildRequires:  python3-base
BuildRequires:  zsh
BuildRequires:  zstd

%description
Just is a command runner. Although it shares
some similarities with "make", it is not a build
system.

%package bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Supplements:    (%{name} and bash-completion)
Requires:       bash-completion
BuildArch:      noarch

%description bash-completion
Bash command-line completion support for %{name}.

%package fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Supplements:    (%{name} and fish)
Requires:       fish
BuildArch:      noarch

%description fish-completion
Fish command-line completion support for %{name}.

%package zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Supplements:    (%{name} and zsh)
Requires:       zsh
BuildArch:      noarch

%description zsh-completion
Zsh command-line completion support for %{name}.

%prep
%autosetup -a1

%build
%{cargo_build} --all-features
mkdir completions
./target/release/just --completions bash > completions/just.bash
./target/release/just --completions fish > completions/just.fish
./target/release/just --completions zsh > completions/just.zsh

%install
./target/release/%{name} --man > %{name}.1
install -Dm0644 %{name}.1 %{buildroot}%{_mandir}/man1/%{name}.1
install -Dm0755 ./target/release/%{name} %{buildroot}%{_bindir}/%{name}
install -Dm0644 -T completions/%{name}.bash %{buildroot}%{_datadir}/bash-completion/completions/%{name}
install -Dm0644 -T completions/%{name}.fish %{buildroot}%{_datadir}/fish/vendor_completions.d/%{name}.fish
install -Dm0644 -T completions/%{name}.zsh %{buildroot}%{_datadir}/zsh/site-functions/_%{name}

%if %{with tests}
%check
# we skip the tests, as they are super flakely
%{cargo_test} --all
%endif

%files
%license LICENSE
%doc *.md
%{_bindir}/%{name}
%{_mandir}/man?/%{name}.?%{?ext_man}

%files bash-completion
%{_datadir}/bash-completion/*

%files fish-completion
%dir %{_datadir}/fish
%{_datadir}/fish/*

%files zsh-completion
%dir %{_datadir}/zsh
%{_datadir}/zsh/*

%changelog
* Thu Jul  3 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 1.41.0:
  * Treat SIGINFO as non-fatal
  * Improve signal handling
  * Add dotenv-override setting
  * Add PATH_SEP and PATH_VAR_SEP constants
  * Add --tempdir command-line option
  * Pin clap_complete to last compatible version
  * Add arkade to readme
  * Link to pipx instead of pypi in readme
  * Add reasons to #[ignore] attributes
  * Mention that command-line environment variables are inherited
  * Fix attribute grammar and update documentation
  * Tweak prose in groups section of readme
  * Update extractions/setup-just version in readme
  * Remove return in Recipe::confirm
  * Add mise to alternatives in readem
  * Update softprops/action-gh-release
  * Use default as name of --init justfile default recipe
  * Add just.systems link to --init justfile
  * Fix kitchen-sink.just comment
  * Update softprops/action-gh-release
  * Fix clippy lints
  * Add back-to-the-top link to readme
  * Placate clippy lints for 1.86
  * Use -S in uv example
  * Handle --request without parsing justfile
- remove unnecessary set_version service
- disable cargo_vendor filtering, as of right now it's bugged
* Fri Jun 13 2025 Richard Rahl <rrahl0@opensuse.org>
- create manpage, so we actually have documentation
* Mon Mar 10 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 1.40.0:
  * Allow the target of aliases to be recipes in submodules
  * Make --list-submodules require --list
  * Star parameters may follow default parameters
  * Remove test! macro from readme
  * Sort enum variant, struct member, and trait members alphabetically
  * Add Zed extension to readme
  * Refactor error checking in choose function
  * Use Test struct instead of test! macro
  * Include unicode codepoint in unknown start of token error
  * Ignore broken pipe error from chooser
  * Guarantee that Namepaths are non-empty
  * Remove unnecessary binding modifiers
  * Document Vim and Neovim built-in syntax highlighting
  * Remove rust:just Repology badge
  * Clarify --list argument
  * Expand Windows path documentation
  * Fix readme typos
* Thu Jan 23 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 1.39.0:
  * Add which() and require() for finding executables
  * Add no-exit-message Setting and [exit-message] attribute
  * Configure alias style in --list with --alias-style
  * Add regex mismatch conditional operator
  * Add read_to_string(path) function
  * Rename read_to_string() to read()
  * Keep [private] attribute when formatting assignments
  * Format if … else if … without superfluous braces
  * Fix error when lexing ! at end-of-file
  * Handle recipes in submodules in fish completion script
  * Add tests for require()
  * Evaluate concatenations and joins from left to right
  * Disable links to empty chapters in book
  * Clarify that trim_*_match functions take subtrings
  * Check attributes in parser instead of analyzer
  * Ignore I/O errors when writing changelog to stdout
  * Add quiet setting and fix typos in readme
  * Update readme to use env() instead of env_var*()
  * Document using || to provide default for empty environment variable
  * Refactor Line predicates
  * Fix typos in README.md
  * Add full example getting XDG user directory to readme
  * Document weird behavior of duplicate definitions in imports
  * Update readme to reflect actual behavior of user directory functions
  * Document running python recipes with uv
  * Sort functions alphabetically
  * Fix truncated bang operator error message
  * Include source path in dump JSON
  * Add attribute set
* Fri Dec 20 2024 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Cleanup specfile
  * use archived tarball from upstream
  * remove cargo_config
- Update vendored dependencies
* Wed Dec 18 2024 Richard Rahl <rrahl0@opensuse.org>
- skip all tests, as for some reason, now other tests are flaky.
  so test have to be done now manually when packaging a newer version.
* Sat Dec 14 2024 Richard Rahl <rrahl0@opensuse.org>
- skip tests which are very flaky on most non x86_64 (even on x86_64,
  it sometimes flakes)
* Wed Dec 11 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.38.0:
  * Add [openbsd] recipe attribute
  * Add [working-directory] recipe attribute
  * Add --allow-missing to ignore missing recipe and submodule errors
  * Add snap package back to readme
  * Forbid duplicate non-repeatable attributes
  * Publish docs to GitHub pages on release only
  * Note lack of support for string interpolation
  * Embolden help text errors
  * Style help text
  * Add --request subcommand for testing
  * [bin/forbid] Improve error message if ripgrep is missing
  * Fix Rust 1.83 clippy warnings
  * Refactor JSON tests
  * Get Config from ExecutionContext instead of passing separately
  * Don't write justfiles unchanged by formatting
- switch to tar_scm, so we can actually offer the correct package-meta
* Wed Nov 20 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.37.0:
  * Add style() function
  * Terminal escape sequence constants
  * Add && and || operators
  * Make recipe doc attribute override comment
  * Don't export constants
  * Allow duplicate imports
  * Publish single SHA256SUM file with releases
  * Mark recipes with private attribute as private in JSON dump
  * Forbid invalid attributes on assignments
  * Add -g to rust-just install instructions
  * Change doc backtick color to cyan
  * Note that set shell is not used for [script] recipes
  * Replace derivative with derive-where
  * Highlight backticks in docs when listing recipes
  * Update setup-just version in README
  * Fix shell function example in readme
  * Update softprops/action-gh-release
  * Use justfile instead of mf on invalid examples in readme
  * Add advice on printing complex strings
  * Document using functions in variable assignments
  * Use prettier string comparison in tests
  * Note shell(…) as an alternative to backticks
  * Add Recipe::subsequents
  * Add subsequents to grammar
  * Document checking releases hashes
  * Show how to access positional arguments with powershell
  * Use -CommandWithArgs instead of -cwa
  * Document -cwa flag for PowerShell positional arguments
  * Use unwrap_or when creating relative path in loader
* Tue Oct  1 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.36.0:
  * Allow default values to use earlier recipe arguments
  * Add `--one` flag to forbid multiple recipes from being invoked
  * Allow including arbitrary characters in strings with `\u{…}`
  * Print recipe doc string when`--explain` flag  is passed
  * Use unwrap_or_default() when getting default color and verbosity
  * De-duplicate suggestion methods
  * Refactor analyzer
  * Use `console` codeblocks in readme
  * Add PyPI install instructions
  * Remove old recipes from project justfile
  * Fix clippy lints
- remove cargo_audit, as it's included in cargo_vendor
* Thu Aug 29 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.35.0:
  * Allow fallback with recipes in submodules
  * Allow [private] attribute on assignments
  * Generate .sha256sum files for release artifacts
  * Clarify that subsequent dependencies run immediately after recipe
  * Remove Config::run
  * Remove logging
  * Group commands under dedicated heading in --help output
* Fri Aug  2 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.34.0:
  * Make function paths relative to correct working directory
  * Keep multi-line shebangs together
* Wed Jul 31 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.33.0:
  * Use correct backtick and shell() expression working directory in submodules
  * Add working-directory setting
  * Allow [group] attribute on submodules
  * Allow empty [script] attribute and add set script-interpreter
  * Document which attributes apply to which items
  * Add missing productions
  * Fix Rust 1.80.0 warnings
  * Remove (no group) header before ungrouped recipes
  * Document script-interpreter setting
  * set dotenv-path does not override set dotenv-filename
* Thu Jul 18 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.32.0:
  * Add unstable [script(…)] attribute
  * Add [extension: 'EXT'] attribute to set shebang recipe script file extension
  * Suppress mod doc comment with empty [doc] attribute
  * Allow [doc] annotation on modules
* Tue Jul 16 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.31.0:
  * Stabilize modules
  * Allow mod path to be directory containing module source
  * Allow enabling unstable features with set unstable
  * Allow abbreviating functions ending in _directory to _dir
  * Lexiclean search directory so .. does not check the current directory
  * Print space before submodules in --list with groups
* Sun Jul  7 2024 Joshua Smith <smolsheep@opensuse.org>
- Update to version 1.30.1:
  Fixes
  * Fix function argument count mismatch error message
- Update to version 1.30.0:
  Fixed
  * Allow comments after mod statements
  Changed
  * Allow unstable features with --summary
  * Don't analyze comments when ignore-comments is set
  * List recipes by group in group justfile order with just
  - -list --unsorted
  * List groups in source order with just --groups --unsorted
  Added
  * Avoid install and add 32-bit arm targets to install.sh
  * Give modules doc comments for --list
  * Add datetime() and datetime_utc() functions
  * Allow setting more command-line options with environment
    variables
  Library
  * Don't exit process in run() on argument parse error
  * Allow passing command-line arguments into run()
  * Ignore env_logger initialization errors
  Misc
  * Tweak readme
  * Add development guide to readme
  * Add shell-expanded string syntax to grammar
  * Add recipe for testing bash completion script
  * Fix use of justfile_directory() in readme
  * Use default values for --list-heading and --list-prefix
  * Use clap::ValueParser
  * Document module doc comments in readme
  * Use -and instead of && in PowerShell completion script
  * Fix readme formatting
  * Link to justfiles on GitHub in readme
  * Link to modules when first introduced in readme
  * Update softprops/action-gh-release
  * Document remote justfile workaround
  * Document library interface
  * Remove dependency on cradle
  * Add note to readme about quoting paths on Windows
  * Add missing changelog credits
  * Credit myself in changelog
* Mon Jun 17 2024 Soc Virnyl Estela <obs@uncomfyhalomacro.pl>
- Various shell completion packages are needed for tests
  * fish, bash, zsh
- Service file update
  * replace glob to avoid vendoring the vendored tarball although likely
    it does not happen but just in case.
  * set filter to true
- Source0 tarball points to github releases/tags
- Remove patch ignore-test.patch.
- Add python for tests
* Sun Jun 16 2024 rrahl0@disroot.org
- Update to version 1.29.1:
  * Release 1.29.1
  * Fix unexport syntax conflicts
  * Release 1.29.0
  * Improve argument parsing and error handling for submodules
  * Document shell expanded string defaults
  * Load environment file from dotenv-path relative to working directory
  * Add [positional-arguments] attribute
  * Test bare bash path in shebang on windows
  * Use `--justfile` in Fish shell completions
  * Test shell not found error messages
  * Add `is_dependency()` function
  * Fix `fzf` chooser preview with space-separated module paths
  * Allow printing nu completion script with `just --completions nushell`
  * Add `[ATTRIBUTE: VALUE]` shorthand
  * Refactor evaluator
  * Allow unexporting environment variables
* Thu Jun  6 2024 rrahl0@disroot.org
- Update to version 1.28.0:
  * Fix man page generation in release workflow
  * Release 1.28.0
  * Don't check in manpage
  * Document default shell
  * Write shebang recipes to $XDG_RUNTIME_DIR
  * Remove duplicate section in Chinese readme
  * Update Chinese readme
  * Fix typo in readme
  * Don't check in auto-generated completion scripts
  * Add `set dotenv-required` to require an environment file
  * Allow listing recipes in submodules with `--list-submodules`
  * Use space-separated recipe paths in `--choose`
  * Don't display submodule recipes in `--list`
  * Show recipes in submodules with `--show RECIPE::PATH`
  * Add `--timestamp-format`
  * Allow listing submodule recipes with `--list PATH`
  * Print recipe command timestamps with `--timestamps`
  * Add `module_file()` and `module_directory()` functions
  * Fix bash completion for aliases
  * Document when dependencies run in readme
  * Build aarch64-pc-windows-msvc release binaries
  * Clarify that `dotenv-path`-given env file is required
  * Print multi-line doc comments before recipe in `--list`
  * List unsorted imported recipes by import depth and offset
  * Update README.md
* Sat May 25 2024 rrahl0@disroot.org
- Update to version 1.27.0:
  * Release 1.27.0
  * Add `[doc]` attribute to set and suppress documentation comments
  * Add source_file() and source_directory() functions
  * List modules in source order with `--unsorted`
  * Add recipe groups
  * Forbid whitespace in shell-expanded string prefixes
  * Add Debian and Ubuntu install instructions to readme
  * Remove snap installation instructions from readme
  * Show submodule recipes in --choose
  * Fallback to wget in install script if curl isn't available(#1913)
  * Use cache dir for temporary files
  * Use std::io::IsTerminal instead of atty crate
  * Improve `shell()` documentation
  * Add bash completion for snap
  * Allow multiple imports of the same file in different modules
  * Fix submodule recipe listing indentation
  * Refactor list subcommand
  * Pass command as first argument to `shell`
  * Add shell() function for running external commands
  * Allow shell expanded strings in mod and import paths
  * Add `--global-justfile` flag
  * Run imported recipes in root justfile with correct working directory
  * Add shell-expanded strings
  * Add `encode_uri_component` function
  * Add `choose` function for generating random strings
  * Add predefined constants
  * Document working directory
  * Replace FunctionContext with Evaluator
  * Allow setting some command-line options with environment variables
  * Add prepend() function
  * Add append() function
  * Add --man subcommand
  * Make `dotenv-path` relative to working directory
  * Update clap to version 4
  * Cleanup
  * Increase --list maximum alignable width from 30 to 50
  * Document using `env -S`
  * Update line continuation documentation
  * Add `assert` expression
  * Add 'allow-duplicate-variables' setting
  * Add example using GNU parallel to run tasks in concurrently
  * Placate clippy: use `clone_into`
  * Use --command-color when printing shebang recipe commands
  * Document how to use watchexec to re-run recipes when files change
  * Fix output `\r\n` stripping
  * Update VS Code extensions in readme
  * Add rust:just repology package table to readme
- add ignore-test.patch, as the backtick test fails only on OBS
* Tue May 14 2024 rrahl0@disroot.org
- Update to version 1.26.0:
  * Update dependencies
  * Clarify that janus operates on public justfiles only
  * Fix Error::TmpdirIo error message
  * Add --no-aliases to hide aliases in --list
  * Add -E as alias for --dotenv-path
  * Rename `delete` example recipe to `delete-all`
- enable upstream tests
* Mon Mar 18 2024 rrahl0@proton.me
- Update to version 1.25.2:
  * Unpin ctrlc
- Update to version 1.25.1:
  * Pin ctrlc to version 3.1.1
  * Fix AArch64 release build error
- Update to version 1.25.0:
  * Add `blake3` and `blake3_file` functions
  * Fix readme typo
  * Use unwrap_or_default
  * Set codegen-units to 1 reduce release binary size
  * Fix install.sh shellcheck warnings
  * Document openSUSE package
- Update to version 1.24.0:
  * Support recipe paths containing `::` in Bash completion script
  * Add function to canonicalize paths
  * Use unlikely-to-be-set variable name in env tests
  * Skip write_error test if running as root
  * Convert run_shebang into integration test
  * Fix typos found by codespell
  * Fix install script
- simplify spec and _service file
- use more macros
* Thu Jan 18 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 1.23.0:
  * Allow setting custom confirm prompt
  * Add `set quiet` and `[no-quiet]`
  * Add `just_pid` function
  * Include completion scripts in releases
  * Run imports in working directory of importer
  * Tweak readme table formatting
  * Add functions to return XDG base directories
  * Don't abbreviate just in README
  * Add `--no-deps` to skip running recipe dependencies
  * Ignore [private] recipes in just --list
  * Add a dash to tempdir prefix
  * Don't conflate recipes with the same name in different modules
  * Clarify that UUID is version 4
  * Make sigil stripping from recipe lines less incomprehensible
  * Refactor invalid path argument check
  * Recipes can be invoked with path syntax
  * Move table of contents pointer to right
  * Add `--format` and `--initialize` as aliases for `--fmt` and `--init`
  * Use box-drawing characters in error messages
  * Optional modules and imports
  * Use Self
  * Print submodule recipes in --summary
  * Expand tilde in import and module paths
  * Document import override behavior
  * Override imported recipes
  * Document submodule working directory
  * Run recipes with working directory set to submodule directory
  * Allow mod statements with path to source file
* Thu Dec 28 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 1.19.0:
  * Add modules
* Mon Dec 25 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 1.18.1:
  * Display a descriptive error for `!include` directives
  * Tweak readme
  * Stabilize `!include path` as `import 'path'`
* Wed Dec 20 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 1.17.0:
  * Pass justfile path to default chooser
  * Pass `--unstable` and `--color always` to default chooser
  * Update Gentoo package repository
  * Fix readme header level
  * Document line continuations
  * List included recipes in load order
  * Rename Justfile::first → Justfile::default
  * Don't default to included recipes
* Sat Dec  2 2023 xtexchooser@duck.com
- Update to version 1.16.0:
  * Fix readme typo
  * Fix Fish completion script
  * Add ARMv6 release target
  * Add `semver_matches` function
  * Clean up error display
  * Misc fixes
  * Fix readme build badge
  * Add `dotenv-filename` and `dotenv-path` settings
  * Fix set tempdir grammar
  * Add version to attributes
  * Allow setting echoed recipe line color
  * Update README.md
* Wed Oct 25 2023 Soc Virnyl Estela <contact@uncomfyhalomacro.pl>
- Update to version 1.15.0:
  * Add Nushell completion script
  * Update Indentation Documentation
  * Allow unstable features to be enabled with environment variable
  * Fix triple-quoted string example in readme
  * README fix: the -d in `mktemp -d` is required to created folders.
  * Placate clippy
  * Add num_cpus() function
  * Document Windows Package Manager install instructions
  * Test unpaired escaped carriage return error
  * Allow escaping newlines
  * Stabilize JSON dump format
  * Avoid grep aliases in bash completions
  * Clarify [unix] attribute in readme
  * Add env() function
  * Add descriptions to fish recipe completions
  * Allow selecting multiple recipes with default chooser
  * Add better documentation for --dump and --fmt
* Sat Sep  2 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Revert update of vendored dependencies.
* Sat Sep  2 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update vendored dependencies
- Update source cargo_config
* Sun Aug 13 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Replace obsoleted `disabled` option with `manual`
* Sat Jun  3 2023 socvirnyl.estela@gmail.com
- Update to version 1.14.0:
  * Ignore clippy::let_underscore_untyped
  * Use `just --show` in default chooser
  * Update README to reflect new attribute syntax
  * Allow multiple attributes on one line
  * Analyze and Compiler tweaks
  * Downgrade to TLS 1.2 in install script
* Sun Mar  5 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Initial spec for just 1.13.0
